#!/bin/bash

AUTHOR="Janne Hellas"
VERSION="1.0"
LICENSE="Public Domain or equivalent."
LINFO="This software is provided \"as-is\" without any warranties or liabilities."

# handle non-option arguments
if [[ $# -ne 1 ]]; then
   echo "FF6 detection script v$VERSION"
   echo ""
   echo "Usage: ./ff6detect.sh [Filename]"
   echo ""
   echo "The utility will detect and return a ff6 version string."
   echo "If ff6 is not detected, the script returns 'default' string."
   echo ""
   echo "License: $LICENSE"
   echo "$LINFO"
   exit 1
fi

if [ ! -f "$1" ];then
   echo "$0: Input file doesn't exist."
   exit 2
fi

# Detect ff6mobile
FF6MOBILE=`xxd -p -l 32 -u "$1" | tr -d " \n"`
if [ "${FF6MOBILE}" == "46494E414C2046414E5441535920564920202020206D6F62696C652020202020" ]; then
   echo "ff6mobile"
   exit 0
fi

# Detect ff6advance
FF6ADV=`xxd -p -l 32 -s 0x1f00 -u "$1" | tr -d " \n"`
if [ "${FF6ADV}" == "46494E414C2046414E544153592056492020202020414456414E434520202020" ]; then
   echo "ff6advance"
   exit 0
fi

# Detect ff3snes
FF3SNES=`xxd -p -l 8 -s 0x1ff8 -u "$1" | tr -d " \n"`
if [ "${FF3SNES}" == "1BE41BE41BE41BE4" ]; then
    echo "ff3snes"
    exit 0
fi

echo "default"
